BackgroundStyleLayer class final Style

Inheritance

Constructors

BackgroundStyleLayer({required String id, bool visible = true, Color color = const Color(0x00000000), double opacity = 1, Map<String, Object> layout = const {}, Map<String, Object> paint = const {}})
Create a new BackgroundStyleLayer.
const

Properties

color Color
The color with which the background will be drawn.
final
filter Object?
A expression specifying conditions on source features. Only features that match the filter are displayed. Zoom expressions in filters are only evaluated at integer zoom levels. The feature-state expression is not supported in filter expressions.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
Unique layer name.
finalinherited
layout Map<String, Object>
Layout properties for the layer.
finalinherited
maxZoom double?
The maximum zoom level for the layer. At zoom levels equal to or greater than the maxzoom, the layer will be hidden.
finalinherited
metadata Map<String, Object?>?
Arbitrary properties useful to track with the layer, but do not influence rendering. Properties should be prefixed to avoid collisions, like 'maplibre:'.
finalinherited
minZoom double?
The minimum zoom level for the layer. At zoom levels less than the minzoom, the layer will be hidden.
finalinherited
opacity double
The opacity at which the background will be drawn.
final
paint Map<String, Object>
Default paint properties for this layer.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
Whether this layer is displayed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited