blur property
Amount to blur the circle. 1 blurs the circle such that only the centerpoint is full opacity.
Implementation
final double blur;
Amount to blur the circle. 1 blurs the circle such that only the centerpoint is full opacity.
final double blur;