ImageSource class final Style

An image source. The url value contains the image location. The coordinates array contains Positions for the image corners listed in clockwise order: top left, top right, bottom right, bottom left.

https://maplibre.org/maplibre-style-spec/sources/#image

Inheritance

Constructors

ImageSource({required String id, required String url, required LngLatQuad coordinates})
The default constructor for a ImageSource object.
const

Properties

coordinates LngLatQuad
Corners of image specified in longitude, latitude pairs.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The id of the source.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
URL that points to an image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited