RasterDemSource class final Style

A raster DEM source. Only supports Mapbox Terrain RGB and Mapzen Terrarium tiles.

https://maplibre.org/maplibre-style-spec/sources/#raster-dem

Inheritance

Constructors

RasterDemSource({required String id, String? url, List<String>? tiles, List<double> bounds = const [-180, -85.051129, 180, 85.051129], double minZoom = 0, double maxZoom = 2, int tileSize = 512, String? attribution, RasterDemEncoding encoding = const RasterDemMapboxEncoding(), bool volatile = false})
The default constructor for a RasterDemSource object.
const

Properties

attribution String?
Contains an attribution to be displayed when the map is shown to a user.
final
bounds List<double>
An array containing the longitude and latitude of the southwest and northeast corners of the source's bounding box in the following order: sw.lng, sw.lat, ne.lng, ne.lat. When this property is included in a source, no tiles outside of the given bounds are requested by MapLibre.
final
encoding RasterDemEncoding
The encoding used by this source. Mapbox Terrain RGB is used by default.
final
hashCode int
The hash code for this object.
no setterinherited
id String
The id of the source.
finalinherited
maxZoom double
Maximum zoom level for which tiles are available, as in the TileJSON spec. Data from tiles at the maxzoom are used when displaying the map at higher zoom levels.
final
minZoom double
Minimum zoom level for which tiles are available, as in the TileJSON spec.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tiles List<String>?
An array of one or more tile source URLs, as in the TileJSON spec.
final
tileSize int
The minimum visual size to display tiles for this layer. Only configurable for raster layers.
final
url String?
A URL to a TileJSON resource. Supported protocols are http: and https:.
final
volatile bool
A setting to determine whether a source's tiles are cached locally.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited