Source class interface Style

The base Source class that can't be used directly.

https://maplibre.org/maplibre-style-spec/sources

Implementers

Constructors

Source({required String id})
Create a new Source instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The id of the source.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited