sourceId property
Name of a source description to be used for this layer. Required for all layer types except background.
Implementation
final String sourceId;
Name of a source description to be used for this layer. Required for all layer types except background.
final String sourceId;