queryLayers abstract method
Queries the map for rendered features at a single point. Returns a list of maps containing all feature properties including layer metadata.
Implementation
Future<List<Map<String, String>>> queryLayers(Offset screenLocation);