The base Layer class that can't be used directly.
- Implementers
Constructors
Properties
- filter → Object?
-
A expression specifying conditions on source features. Only features that
match the filter are displayed. Zoom expressions in filters are only
evaluated at integer zoom levels. The feature-state expression is not
supported in filter expressions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique layer name.
final
-
layout
→ Map<
String, Object> -
Layout properties for the layer.
final
- maxZoom → double?
-
The maximum zoom level for the layer. At zoom levels equal to or greater
than the maxzoom, the layer will be hidden.
final
-
metadata
→ Map<
String, Object?> ? -
Arbitrary properties useful to track with the layer, but do not influence
rendering. Properties should be prefixed to avoid collisions,
like 'maplibre:'.
final
- minZoom → double?
-
The minimum zoom level for the layer. At zoom levels less than the
minzoom, the layer will be hidden.
final
-
paint
→ Map<
String, Object> -
Default paint properties for this layer.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited